pyvisco.shift
=============

.. automodule:: pyvisco.shift

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      WLF
      fit_WLF
      fit_poly
      plot
      poly1
      poly2
      poly3
      poly4
   
   

   
   
   

   
   
   



